@@ -8,13 +8,7 @@ from rcon.source import rcon as _rcon
 from rcon.source import Client as _Client
 
 
-__all__ = [
-    'EmptyResponse',
-    'SessionTimeout',
-    'WrongPassword',
-    'Client',
-    'rcon'
-]
+__all__ = ["EmptyResponse", "SessionTimeout", "WrongPassword", "Client", "rcon"]
 
 
 class Client(_Client):
@@ -22,9 +16,9 @@ class Client(_Client):
 
     def __init__(self, *args, **kwargs):
         warn(
-            'rcon.Client() is deprecated. Use rcon.source.Client() instead.',
+            "rcon.Client() is deprecated. Use rcon.source.Client() instead.",
             DeprecationWarning,
-            stacklevel=2
+            stacklevel=2,
         )
         super().__init__(*args, **kwargs)
 
@@ -33,8 +27,8 @@ def rcon(*args, **kwargs) -> Coroutine[Any, Any, str]:
     """Wrapper for rcon.source.rcon() for backwards compatibility."""
 
     warn(
-        'rcon.rcon() is deprecated. Use rcon.source.rcon() instead.',
+        "rcon.rcon() is deprecated. Use rcon.source.rcon() instead.",
         DeprecationWarning,
-        stacklevel=2
+        stacklevel=2,
     )
     return _rcon(*args, **kwargs)
