@@ -4,4 +4,4 @@ from rcon.battleye.client import Client
 from rcon.battleye.proto import ServerMessage
 
 
-__all__ = ['Client', 'ServerMessage']
+__all__ = ["Client", "ServerMessage"]
