@@ -4,4 +4,4 @@ from rcon.source.async_rcon import rcon
 from rcon.source.client import Client
 
 
-__all__ = ['Client', 'rcon']
+__all__ = ["Client", "rcon"]
