@@ -8,7 +8,7 @@ from logging import getLogger
 from random import randint
 from typing import IO, NamedTuple
 
-from rcon.exceptions import EmptyResponse
+from rcon.exceptions import EmptyResponse, UnexpectedTerminator
 
 
 __all__ = ["LittleEndianSignedInt32", "Type", "Packet", "random_request_id"]
@@ -118,7 +118,9 @@ class Packet(NamedTuple):
         return size + payload
 
     @classmethod
-    async def aread(cls, reader: StreamReader) -> Packet:
+    async def aread(
+        cls, reader: StreamReader, raise_unexpected_terminator: bool = False
+    ) -> Packet:
         """Read a packet from an asynchronous file-like object."""
         LOGGER.debug("Reading packet asynchronously.")
         size = await LittleEndianSignedInt32.aread(reader)
@@ -137,12 +139,14 @@ class Packet(NamedTuple):
         LOGGER.debug("  => terminator: %s", terminator)
 
         if terminator != TERMINATOR:
+            if raise_unexpected_terminator:
+                raise UnexpectedTerminator(terminator)
             LOGGER.warning("Unexpected terminator: %s", terminator)
 
         return cls(id_, type_, payload, terminator)
 
     @classmethod
-    def read(cls, file: IO) -> Packet:
+    def read(cls, file: IO, raise_unexpected_terminator: bool = False) -> Packet:
         """Read a packet from a file-like object."""
         LOGGER.debug("Reading packet.")
         size = LittleEndianSignedInt32.read(file)
@@ -161,6 +165,8 @@ class Packet(NamedTuple):
         LOGGER.debug("  => terminator: %s", terminator)
 
         if terminator != TERMINATOR:
+            if raise_unexpected_terminator:
+                raise UnexpectedTerminator(terminator)
             LOGGER.warning("Unexpected terminator: %s", terminator)
 
         return cls(id_, type_, payload, terminator)
@@ -174,6 +180,11 @@ class Packet(NamedTuple):
             b" ".join(map(partial(str.encode, encoding=encoding), args)),
         )
 
+    @classmethod
+    def make_empty_response(cls) -> Packet:
+        """Create an empty response packet."""
+        return cls(random_request_id(), Type.SERVERDATA_RESPONSE_VALUE, b"")
+
     @classmethod
     def make_login(cls, passwd: str, *, encoding: str = "utf-8") -> Packet:
         """Create a login packet."""
